from __future__ import absolute_import

from django.conf import settings
from django.conf.urls import url
from django.views import static
from .test_app.views import HomeView


urlpatterns = [
    url(r'^$', HomeView.as_view()),
    # required since Django 1.7
    url(r'^static', static.serve, {'document_root': settings.STATIC_ROOT}),
]



from selenium.common.exceptions import NoSuchElementException
import pytest
import time


@pytest.fixture
def selenium(selenium):
    selenium.implicitly_wait(10)
    selenium.maximize_window()
    return selenium


def test_banner_shows_and_hides(selenium, live_server):
    selenium.get(live_server.url)
    cookielaw_banner = selenium.find_element_by_id('CookielawBanner')

    # on click of the button, cookie set and banner hidden
    cookielaw_banner.find_element_by_class_name('btn').click()
    assert not cookielaw_banner.is_displayed()
    assert '1' == selenium.get_cookie('cookielaw_accepted')['value']

    # on come back, assert banner gone
    selenium.get(live_server.url)

    with pytest.raises(NoSuchElementException):
        selenium.find_element_by_id('CookielawBanner')


def test_banner_shows_and_hides_with_jquery(selenium, live_server):
    # now, with jQuery
    selenium.get('{}/?jquery=1'.format(live_server.url))
    cookielaw_banner = selenium.find_element_by_id('CookielawBanner')

    # on click of the button, cookie set and banner hidden
    cookielaw_banner.find_element_by_class_name('btn').click()
    time.sleep(1)
    assert not cookielaw_banner.is_displayed()
    assert '1' == selenium.get_cookie('cookielaw_accepted')['value']



import warnings
import django

from classytags.helpers import InclusionTag
from django import template
from django.template.loader import render_to_string


register = template.Library()


class CookielawBanner(InclusionTag):
    """
    Displays cookie law banner only if user has not dismissed it yet.
    """

    template = 'cookielaw/banner.html'

    def render_tag(self, context, **kwargs):
        template_filename = self.get_template(context, **kwargs)

        if 'request' not in context:
            warnings.warn('No request object in context. '
                          'Are you sure you have django.core.context_processors.request enabled?')
            return ''

        elif context['request'].COOKIES.get('cookielaw_accepted', False):
            return ''

        data = self.get_context(context, **kwargs)

        if django.VERSION[:2] < (1, 10):
            return render_to_string(template_filename, data, context_instance=context)
        else:
            return render_to_string(template_filename, data, getattr(context, 'request', None))

register.tag(CookielawBanner)



import six
import pytest
from django.utils.translation import ugettext as _


@pytest.fixture()
def content(client):
    response = client.get('/')
    assert 200 == response.status_code

    if isinstance(response.content, six.binary_type):
        return response.content.decode('utf-8')  # py3 comapt

    return response.content


def test_banner_shows(content):
    assert 'CookielawBanner' in content


def test_banner_contains_correct_text(content):
    assert _('COOKIE_INFO_HEADER') in content
    assert _('COOKIE_INFO_PARA') in content
    assert _('COOKIE_INFO_OK') in content



#!/usr/bin/env python

import os
from setuptools import setup, find_packages
from itertools import chain
from glob import glob

import cookielaw


CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Web Environment',
    'Framework :: Django',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: JavaScript',
    'Topic :: Internet :: WWW/HTTP',
    'Topic :: Internet :: WWW/HTTP :: Session',
]

package_data_globs = (
    'cookielaw/templates/cookielaw/*.html',
    'cookielaw/static/cookielaw/*/*',
    'cookielaw/locale/*/*/*'
)

package_data = []
for f in chain(*map(glob, package_data_globs)):
    package_data.append(f.split('/', 1)[1])

setup(
    author='Piotr Kilczuk',
    author_email='piotr@tymaszweb.pl',
    name='django-cookie-law',
    version='.'.join(str(v) for v in cookielaw.VERSION),
    description='Helps your Django project comply with EU cookie law regulations',
    long_description=open(os.path.join(os.path.dirname(__file__), 'README.rst')).read(),
    url='https://github.com/TyMaszWeb/django-cookie-law',
    license='BSD License',
    platforms=['OS Independent'],
    classifiers=CLASSIFIERS,
    install_requires=[
        'Django>=1.8',
        'django-classy-tags>=0.3.0',
        'pytest-runner>=2.11.1'
    ],
    tests_require=[
        'six',
        'pytest>=3.0.0',
        'pytest-django>=3.1.2',
        'pytest-selenium>=1.9.1',
        'selenium>=3.3.1',
    ],
    packages=find_packages(),
    package_data={'cookielaw': package_data},
    include_package_data=False,
    zip_safe=False,
    test_suite='tests',
)
